@@ -16,7 +16,6 @@
 
 #include <QLoggingCategory>
 #include <QDir>
-#include <QTimer>
 #include <QCommandLineParser>
 #include <QApplication>
 #include <QProcess>
@@ -56,7 +55,7 @@ extern QDBUS_EXPORT void qDBusAddSpyHook(void (*)(const QDBusMessage &));
 static void runKonfUpdate()
 {
     QProcess kconfUpdate;
-    kconfUpdate.start(QStringLiteral(KCONF_UPDATE_EXE));
+    kconfUpdate.start(QStringLiteral(KCONF_UPDATE_EXE), QStringList());
     kconfUpdate.waitForFinished();
 }
 
